.. include:: ../README.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   cli
   loop
   CWLProv
   pythonversions
   processgen
   autoapi/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
